#
# spec file for package ghc-network
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name network
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.6.3.2
Release:        lp150.1.8
Summary:        Low-level networking interface
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
%endif

%description
This package provides a low-level networking interface.

In network-2.6 the 'Network.URI' module was split off into its own package,
network-uri-2.6. If you're using the 'Network.URI' module you can automatically
get it from the right package by adding this to your .cabal file:

> flag network-uri > description: Get Network.URI from the network-uri package
> default: True > > library > -- ... > if flag(network-uri) > build-depends:
network-uri >= 2.6, network >= 2.6 > else > build-depends: network-uri < 2.6,
network < 2.6

That is, get the module from either network < 2.6 or from network-uri >= 2.6.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md examples

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 2.6.3.2 revision 1.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 2.6.3.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.6.2.1 revision 0 with cabal2obs.
* Mon Jul 13 2015 mimi.vx@gmail.com
- update to 2.6.2.1
  * Regenerate configure and HsNetworkConfig.h.in.
  * Better detection of CAN sockets.
  * Add support for TCP_USER_TIMEOUT.
  * Don't conditionally export the SockAddr constructors.
  * Add isSupportSockAddr to allow checking for supported
  address types at runtime.
* Sun May 31 2015 mimi.vx@gmail.com
- update to 2.6.2.0
  * no upstream changelog
* Sun May 10 2015 mimi.vx@gmail.com
- update to 2.6.1.0
  * no upstream changelog
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 2.6.0.2
  * split to network and network-uri packages
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 2.4.2.3
  * no changelog
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.4.1.2 from upstream
  * no changelog
  * see https://github.com/haskell/network for commit messages
- update needed for Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Mon Jan  7 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- downgrade to 2.3.1.0 for Haskell Platform 2012.4.0.0
  * cabal-install requires < 2.4
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- update to 2.4.0.1 from upstream
- required by Haskell Platform 2012.4.0.0
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 2.3.0.13 from upstream
  * Add Num constraint to packBits, unpackBits
  * Turn off some build warnings
  * Network.URI: remove dropHead, use 'drop 1'
- spec file template generated by cabal2spec-0.25.5
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Adjusted version for platform 2011.4
* Wed Dec 14 2011 peter.trommler@ohm-hochschule.de
- Fix defattr
* Wed Dec 14 2011 peter.trommler@ohm-hochschule.de
- Added rpmlintrc and BR ghc libraries
* Tue Nov  1 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
